@@ -35,22 +35,58 @@
     email: maasir554@gmail.com
 
 """
+
 import math
+from turtle import degrees
 
 
 class vector:
     
     #Constructor
-
-    def __init__(self, i, j, k):
+    # may us *args and *kwargs method later but as of now i dont have time
+    #it is a WAY better method in some cases.!
+    
+    def __init__(self, i=0, j=0, k=0):      # component will take value 0 if not specified. 
         #Rectangular Components in i,j,k
-        self.i = i
-        self.j = j
-        self.k = k
+        if (type(i) == int or type(i) == float) and (type(j) == int or type(j) == float) and (type(k) == int or type(k) == float):
+            self.i = i
+            self.j = j
+            self.k = k
+        elif type(i) == list:
+            self.i = i[0]
+            self.j = i[1]
+            self.k = i[2]
+        elif type(i) == tuple:
+            self.i = i[0]
+            self.j = i[1]
+            self.k = i[2]
+        elif type(i) == dict :
+            if 'i' in i and 'j' in i and 'k' in i:
+                self.i = i['i']
+                self.j = i['j']
+                self.k = i['k']
+            elif 'x' in i and 'y' in i and 'z' in i:
+                self.i = i['x']
+                self.j = i['y']
+                self.k = i['z']
+            else:
+                raise ValueError("Invalid input")
+        elif type(i) == str:
+            lst = i.split(' ')
+            if len(lst) == 3:
+                    self.i = float(lst[0])
+                    self.j = float(lst[1])
+                    self.k = float(lst[2])
+            else:
+                raise ValueError("Invalid input")
+
+
+
+        
         #Rectangular Components in x,y,z
-        self.x = i
-        self.y = j
-        self.z = k
+        self.x = self.i
+        self.y = self.j
+        self.z = self.k
         #Magnitude
         self.magnitude = self.__magnitude()  #refer to __magnitude() below
         self.modulus = self.magnitude
@@ -64,10 +100,28 @@ class vector:
         #Unit Vector [Tuple] along the vector (parallel)
         # NOTE !WARNING! the unit_vector function returns a TUPLE (x,y,z) and NOT a vector
         self.unit_vector = (self.__unit_vector())
-
+        self.direction = self.unit_vector
 
         self.type = self.__type__()
 
+        #angle made by vector with the coordinate axes x,y and z respectively :
+        if self.magnitude != 0:    
+            self.angle_x = math.acos(self.i/self.magnitude)
+            
+            self.angle_y = math.acos(self.j/self.magnitude)
+            
+            self.angle_z = math.acos(self.k/self.magnitude)
+        else:
+            self.angle_x = 0
+            self.angle_y = 0
+            self.angle_z = 0
+        # degrees:
+        self.angle_x_deg = self.angle_x * 180 / math.pi
+        self.angle_y_deg = self.angle_y * 180 / math.pi
+        self.angle_z_deg = self.angle_z * 180 / math.pi
+        
+        
+
     #String representation of the vector object :
 
     def __type__(self):
@@ -110,7 +164,7 @@ class vector:
     # function to return unit_vector in different (string) formats 
     def unit_vector(self, format="default"):
         if format == "csv" or format == "tuple" or format == "default":
-            return(self.unit_vector)
+            return(self.__unit_vector)
         elif format == "componential" or format =="components" or format == "comp":
             return("({}i + {}j + {}k)".format(self.x, self.y, self.z))
 
@@ -126,7 +180,7 @@ class vector:
             return(self.i * other.i + self.j * other.j + self.k * other.k)
         else:
             return("Error: Invalid input")
-    #if salar number is wrir=tten in the beging, we uses __rmul__ overloader [Magic Method]
+    # if scalar number is wrritten in the beging, we uses __rmul__ overloader [Magic Method]
     def __rmul__(self, other):
         if type(other) == int or type(other) == float:
             return(vector(self.i * other, self.j * other, self.k * other))
@@ -210,6 +264,15 @@ class vector:
     ########### More Dunder methods / Magic methods to be added #############
 
 
+    # Unary operator overloading :-
+    # NOTE : + is the unary plus operator in this case
+    def __pos__(self):
+        return self
+    # NOTE : - is the unary minus operator in this case
+    def __neg__(self):
+        return vector(-self.i, -self.j, -self.k)
 
 
-# i will write i cap as i_
\ No newline at end of file
+
+# i will write i cap as i_
+
